==> mgu74a.db_2.2.0.tar.gz: mgu74a.db/man/mgu74a_dbconn.Rd <==
\name{mgu74a_dbconn}

\alias{mgu74a_dbconn}
\alias{mgu74a_dbfile}
\alias{mgu74a_dbschema}
\alias{mgu74a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mgu74a_dbconn()
  mgu74a_dbfile()
  mgu74a_dbschema(file="", show.indices=FALSE)
  mgu74a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mgu74a_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mgu74a_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mgu74a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mgu74a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mgu74a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mgu74a_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mgu74a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mgu74a_dbschema}: none (invisible \code{NULL}).

  \code{mgu74a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mgu74a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mgu74a_dbconn() was created with:
  dbConnect(SQLite(), dbname=mgu74a_dbfile(), cache_size=64000, synchronous=0)

  mgu74a_dbschema()

  mgu74a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mgu74a.db_2.7.1.tar.gz: mgu74a.db/man/mgu74a_dbconn.Rd <==

\name{mgu74a_dbconn}

\alias{mgu74a_dbconn}
\alias{mgu74a_dbfile}
\alias{mgu74a_dbschema}
\alias{mgu74a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mgu74a_dbconn()
  mgu74a_dbfile()
  mgu74a_dbschema(file="", show.indices=FALSE)
  mgu74a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mgu74a_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mgu74a_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mgu74a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mgu74a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mgu74a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mgu74a_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mgu74a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mgu74a_dbschema}: none (invisible \code{NULL}).

  \code{mgu74a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mgu74a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mgu74a_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mgu74a_dbfile(), cache_size=64000,
  synchronous=0)

  mgu74a_dbschema()

  mgu74a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
